aboutsummaryrefslogtreecommitdiffstats
path: root/Source/SPAppController.m
diff options
context:
space:
mode:
authorstuconnolly <stuart02@gmail.com>2009-11-19 22:02:45 +0000
committerstuconnolly <stuart02@gmail.com>2009-11-19 22:02:45 +0000
commit8110678ed8c66a5daf2223d1ca53956d97edee23 (patch)
tree01a4a6228eefb1ee073014b9af3300991d4e95f8 /Source/SPAppController.m
parentdaa5efe61df282fe602210b5b955a7d21206bf1e (diff)
downloadsequelpro-8110678ed8c66a5daf2223d1ca53956d97edee23.tar.gz
sequelpro-8110678ed8c66a5daf2223d1ca53956d97edee23.tar.bz2
sequelpro-8110678ed8c66a5daf2223d1ca53956d97edee23.zip
The result of being bored. Add a nicer looking about panel based on Adium's.
Diffstat (limited to 'Source/SPAppController.m')
-rw-r--r--Source/SPAppController.m13
1 files changed, 12 insertions, 1 deletions
diff --git a/Source/SPAppController.m b/Source/SPAppController.m
index 49f8c201..86c5fe38 100644
--- a/Source/SPAppController.m
+++ b/Source/SPAppController.m
@@ -27,6 +27,7 @@
#import "SPAppController.h"
#import "TableDocument.h"
#import "SPPreferenceController.h"
+#import "SPAboutController.h"
#import "TableDump.h"
#import "SPEncodingPopupAccessory.h"
#import "SPConstants.h"
@@ -295,7 +296,17 @@
#pragma mark IBAction methods
/**
- * Opens the preferences window
+ * Opens the about panel.
+ */
+- (IBAction)openAboutPanel:(id)sender
+{
+ if (!aboutController) aboutController = [[SPAboutController alloc] init];
+
+ [aboutController showWindow:self];
+}
+
+/**
+ * Opens the preferences window.
*/
- (IBAction)openPreferences:(id)sender
{